use CorpDB;
go

-- Create and load a table with customer summary information.

-- drop table if exists dbo.CustomerInfo;
create table dbo.CustomerInfo
(
	CustomerID int not null,
	FirstName varchar(50) not null,
	LastName varchar(50) not null,
	OrderCount int not null default(0),
	FirstOrderDate datetime null,
	LastOrderDate datetime null
);
go

insert CustomerInfo (CustomerID, FirstName, LastName)
select CustomerID, FirstName, LastName
from dbo.Customer c;

update dbo.CustomerInfo
set OrderCount = o.OrderCount,
	FirstOrderDate = o.FirstOrderDate,
	LastOrderDate = o.LastOrderDate
from dbo.CustomerInfo c
join
(
	select oh.CustomerId, count(oh.OrderId) OrderCount, min(oh.OrderDate) FirstOrderDate, max(oh.OrderDate) LastOrderDate
	from dbo.OrderHeader oh
	group by oh.CustomerId
) o on c.CustomerID = o.CustomerId;
go

-- Find a customer who has no orders
select top (1) *, %%physloc%% physloc, sys.fn_PhysLocFormatter(%%physloc%%) physloc_formatted
from dbo.CustomerInfo
where OrderCount = 0;
go

select *, %%physloc%% physloc, sys.fn_PhysLocFormatter(%%physloc%%) physloc_formatted
from dbo.CustomerInfo
where CustomerID in (20025, 20026);
go

-- Use the values in the physloc_formatted column
dbcc traceon (3604);
dbcc page ('CorpDB', 1, 6406, 3);
